@@ -20,8 +20,8 @@ class AmentPythonTestTask(TaskExtensionPoint):
     async def test(self):  # noqa: D102
         args = self.context.args
         logger.info(
-            "Testing ROS package in '{args.path}' with build type"
-            "'ament_python'".format_map(locals()))
+            f"Testing ROS package in '{args.path}' with build type"
+            "'ament_python'")
 
         # reuse Python test task
         extension = PythonTestTask()
